Enum Error

#[non_exhaustive]
pub enum Error {
Show 36 variants Failure = -1, Stream = -2, Data = -3, MemoryAlloc = -4, ReadBuffer = -5, WriteBuffer = -6, CodecSupport = -7, CodecParam = -8, CodecDict = -9, VersionSupport = -10, InvalidHeader = -11, InvalidParam = -12, FileRead = -13, FileWrite = -14, FileOpen = -15, NotFound = -16, RunLength = -17, FilterPipeline = -18, ChunkInsert = -19, ChunkAppend = -20, ChunkUpdate = -21, TwoGbLimit = -22, SchunkCopy = -23, FrameType = -24, FileTruncate = -25, ThreadCreate = -26, Postfilter = -27, FrameSpecial = -28, SChunkSpecial = -29, PluginIO = -30, FileRemove = -31, NullPointer = -32, InvalidIndex = -33, MetalayerNotFound = -34, MaxBufsizeExceeded = -35, Tuner = -36,
}
Error codes for the blosc2 library.

Note that the error are codes that do not contain any additional information. For debugging purposes, you can set the environment variable BLOSC_TRACE to get many more trace prints that can help you understand what went wrong.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Failure = -1

Generic failure



Stream = -2

Bad stream



Data = -3

Invalid data



MemoryAlloc = -4

Memory alloc/realloc failure



ReadBuffer = -5

Not enough space to read



WriteBuffer = -6

Not enough space to write



CodecSupport = -7

Codec not supported



CodecParam = -8

Invalid parameter supplied to codec



CodecDict = -9

Codec dictionary error



VersionSupport = -10

Version not supported



InvalidHeader = -11

Invalid value in header



InvalidParam = -12

Invalid parameter supplied to function



FileRead = -13

File read failure



FileWrite = -14

File write failure



FileOpen = -15

File open failure



NotFound = -16

Not found



RunLength = -17

Bad run length encoding



FilterPipeline = -18

Filter pipeline error



ChunkInsert = -19

Chunk insert failure



ChunkAppend = -20

Chunk append failure



ChunkUpdate = -21

Chunk update failure



TwoGbLimit = -22

Sizes larger than 2gb not supported



SchunkCopy = -23

Super-chunk copy failure



FrameType = -24

Wrong type for frame



FileTruncate = -25

File truncate failure



ThreadCreate = -26

Thread or thread context creation failure



Postfilter = -27

Postfilter failure



FrameSpecial = -28

Special frame failure



SChunkSpecial = -29

Special super-chunk failure



PluginIO = -30

IO plugin error



FileRemove = -31

Remove file failure



NullPointer = -32

Pointer is null



InvalidIndex = -33

Invalid index



MetalayerNotFound = -34

Metalayer has not been found



MaxBufsizeExceeded = -35

Max buffer size exceeded



Tuner = -36

Tuner failure