Module util

Module util 

Utility functions and types.

This module define the [f16] and Complex types. If the half or num-complex features are enabled, the corresponding types are re-exported from the half and num-complex crates respectively. Otherwise, simple structs are defined, providing a minimal implementation with conversions from/to bits, without any arithmetic operations.

Structs

Complex
A complex number in Cartesian form.
FfiVec
A vector similar to Vec<T>, but allocated using C’s malloc and freed using free.
f16
A 16-bit floating point type implementing the IEEE 754-2008 standard binary16 a.k.a “half” format.

Enums

CowVec
A super type of either a Vec<T>, an FfiVec<T> or a borrowed slice of type &[T].
MmapMode
Memory-mapped mode for opening a super chunk.